<?php
/**
 * Perforce Swarm
 *
 * @copyright   2013-2021 Perforce Software. All rights reserved.
 * @license     Please see LICENSE.txt in top-level readme folder of this distribution.
 * @version     2020.2/2065513
 */

use Jobs\Model\JobDAO;
use Application\Config\IDao;
use Application\Factory\InvokableServiceFactory;

return [
    'router' => [
        'routes' => [
            'job' => [
                'type' => 'Application\Router\Regex',
                'options' => [
                    'regex'    => '/jobs?(/(?P<job>.*))?',
                    'spec'     => '/jobs/%job%',
                    'defaults' => [
                        'controller' => Jobs\Controller\IndexController::class,
                        'action'     => 'job',
                        'job'        => null
                    ],
                ],
            ],
            'jobs' => [
                'type' => 'Application\Router\Regex',
                'options' => [
                    'regex'    => '/jobs?(/(?P<job>.*))?',
                    'spec'     => '/jobs/%job%',
                    'defaults' => [
                        'controller' => Jobs\Controller\IndexController::class,
                        'action'     => 'job',
                        'job'        => null
                    ],
                ],
            ],
        ],
    ],
    'controllers' => [
        'factories' => [
            Jobs\Controller\IndexController::class => Application\Controller\IndexControllerFactory::class
        ],
    ],
    'view_manager' => [
        'template_map' => [
            'jobs/index/index'  => __DIR__ . '/../view/jobs/index/job.phtml',
        ],
        'template_path_stack'   => [
            __DIR__ . '/../view',
        ],
    ],
    'service_manager' => [
        'aliases' => [
            IDao::JOB_DAO => JobDAO::class
        ],
        'factories' => [
            JobDAO::class => InvokableServiceFactory::class
        ]
    ],
    'menu_helpers' => [
        'jobs' => [
            'class'    => '\Projects\Menu\Helper\ProjectAwareMenuHelper',
            'priority' => 170
        ]
    ]
];
